![Oracle Logo](https://raw.githubusercontent.com/oracle/dotnet-db-samples/master/images/oracle-nuget.png) 
# Oracle.ManagedDataAccess 23.3.2-dev
Release Notes for Oracle Data Provider for .NET, Managed Driver NuGet Package

March 2024

Managed Oracle Data Provider for .NET (ODP.NET) features optimized ADO.NET data access to the Oracle database for .NET Framework and is 100% managed code. ODP.NET allows developers to take advantage of advanced Oracle database functionality, including Real Application Clusters, self-tuning statement cache, Application Continuity, JSON Relational Duality, and Fast Connection Failover. 

This document provides information that supplements the [Oracle Data Provider for .NET (ODP.NET) documentation](https://docs.oracle.com/en/database/oracle/oracle-database/23/odpnt/index.html).

## Oracle .NET Links
* [Oracle .NET Home Page](https://www.oracle.com/database/technologies/appdev/dotnet.html)
* [GitHub - Sample Code](https://github.com/oracle/dotnet-db-samples)
* [ODP.NET Discussion Forum](https://forums.oracle.com/ords/apexds/domain/dev-community/category/odp-dot-net)
* [YouTube](https://www.youtube.com/user/OracleDOTNETTeam)
* [X (Twitter)](https://twitter.com/oracledotnet)
* [Email Newsletter Sign Up](https://go.oracle.com/LP=28277?elqCampaignId=124071&nsl=onetdev)

## New Features
* .NET Metrics
     .NET Metrics are application numerical measurements collected at regular time intervals for the purposes of monitoring and alerting about application health. In an ODP.NET setting, metrics can monitor connection statistics, such as number of ODP.NET hard connections to the database, number of active connections, or number of free connections. Starting with version 23.3.2, managed ODP.NET supports .NET Metrics.
     Note: The ODP.NET metrics source name is "Oracle.ManagedDataAccess" for managed ODP.NET.
* OpenTelemetry – Automatic Instrumentation and Dynamic Enablement
     ODP.NET adds new OpenTelemetry automatic instrumentation support that delivers traces to observability backends without requiring source code changes. ODP.NET OpenTelemetry is now enabled automatically. It no longer requires adding Oracle.ManagedDataAccess.OpenTelemetry NuGet package nor calling AddOracleDataProviderInstrumentation() extension method to enable OpenTelemetry.
     ODP.NET OpenTelemetry is now enabled by default. It can be turned off or on by setting OracleConfiguration.OpenTelemetryTracing to false or true, respectively. It can also be set in the OpenTelemetryTracing .NET configuration file setting for .NET Framework.
     Note: The ODP.NET activity source name is "Oracle.ManagedDataAccess" for managed ODP.NET.
     Note: Applications will still need to add Oracle.ManagedDataAccess.OpenTelemetry NuGet package to the application and call the AddOracleDataProviderInstrumentation() extension method by passing in an OracleDataProviderInstrumentationOptions object to set non-default option settings.


## Bug Fixes since Oracle.ManagedDataAccess 23.3.1-dev
* Bug 35711274 ORA-00904: SHARDED INVALID IDENTIFIER WHEN ADDING EVENT HANDLER TO ORACLEAQQUEUE.MESSAGEAVAILABLE
* Bug 35666844 ORA-50000: CONNECTION REQUEST TIMED OUT WHEN USING ASYNC AND CONNECTION POOLING
* Bug 35698455 ORA-50028: INVALID PARAMETER BINDING WHEN USING ARRAY BINDING WITH ASYNC APIS
* Bug 35711258 AQ ORACLEAQAGENT CONSTRUCTOR WITH NULL NAME PARAMETER CAUSES ARGUMENTNULLEXCEPTION
* Bug 35778668 PIPELINING OPERATION BLOCKS THE APPLICATION THREAD
* Bug 35901069 ORA-50028: INVALID PARAMETER BINDING (PARAMETER '1') WHEN USING BIND BY NAME WITH UDTS


## Installation Changes
The following app/web.config entries are added when installing the managed ODP.NET NuGet package to your application:

1) Configuration Section Handler

A configuration section handler entry is added to the app/web.config to enable applications to add an <oracle.manageddataaccess.client> 
section for ODP.NET, Managed Driver-specific configuration.

Note: For a web app, if the same config section handler for "oracle.manageddataaccess.client" also exists in machine.config but the "Version" attribute values are different, an error message "There is a duplicate 'oracle.manageddataaccess.client' section defined." may be observed at runtime. To resolve the error, remove the "oracle.manageddataaccess.client" config section handler entry in the machine.config. If other applications on the machine depend on this machine.config entry, move the config section handler entry to each application's web.config file.

2) DbProviderFactories

The DbProviderFactories entry is added for applications that use DbProviderFactories and DbProviderFactory classes. Any DbProviderFactories entry for "Oracle.ManagedDataAccess.Client" in the machine.config will be ignored. 

3) Dependent Assembly

The dependent assembly entry is created to ignore policy DLLs for Oracle.ManagedDataAccess.dll. It directs the app to always use the Oracle.ManagedDataAccess.dll version that is specified by the "newVersion" attribute in the "bindingRedirect" element. The "newVersion" attribute corresponds to the Oracle.ManagedDataAccess.dll version which came with the NuGet package.

4) Data Sources

The data sources entry is added to provide a template on how a data source can be configured in the app/web.config. 
Simply rename the sample data source to an alias of your choosing; modify the PROTOCOL, HOST, PORT, SERVICE_NAME as required; 
and un-comment the "dataSource" element. Once that is done, the alias can be used as the "data source" attribute in 
your ODP.NET connection string.


 Copyright (c) 2024, Oracle and/or its affiliates.
